@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_events._jsii
@@ -17,7 +17,7 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-sns", "1.62.0", __name__[0:-6], "aws-sns@1.62.0.jsii.tgz"
+    "@aws-cdk/aws-sns", "1.64.1", __name__[0:-6], "aws-sns@1.64.1.jsii.tgz"
 )
 
 __all__ = [
